@@ -6,10 +6,10 @@ import errno
 import uuid
 import argparse
 
-from circus import zmq
-from zmq.eventloop import ioloop, zmqstream
+import zmq
 from zmq.utils.jsonapi import jsonmod as json
 
+from circus._zmq import ioloop, zmqstream
 from circus import logger, __version__
 from circus.client import make_message, cast_message
 from circus.util import (debuglog, to_bool, resolve_name, close_on_exec,
