@@ -3,10 +3,10 @@ from collections import defaultdict
 
 from circus import util
 from circus import logger
+from circus._zmq import ioloop
 
 from select import select
 import socket
-from zmq.eventloop import ioloop
 
 
 class BaseStatsCollector(ioloop.PeriodicCallback):
