@@ -1,5 +1,4 @@
-import time
-from circus.tests.support import TestCircus
+from circus.tests.support import TestCircus, poll_for
 
 
 def Dummy(test_file):
@@ -12,10 +11,4 @@ class TestRunner(TestCircus):
 
     def test_dummy(self):
         test_file = self._run_circus('circus.tests.test_runner.Dummy')
-        time.sleep(1.)
-
-        # check that the file has been filled
-        with open(test_file) as f:
-            content = f.read()
-
-        self.assertTrue('.' in content)
+        self.assertTrue(poll_for(test_file, '..........'))
