@@ -1,12 +1,14 @@
+from __future__ import unicode_literals
+
 import grp
-import os
 import pwd
 import unittest
 from psutil import Popen
+from mock import Mock, patch
+
 
 from circus.util import (get_info, bytes2human, to_bool, parse_env_str,
-                         env_to_str, to_uid, to_gid, replace_gnu_args,
-                         StrictConfigParser)
+                         env_to_str, to_uid, to_gid, replace_gnu_args)
 
 
 class TestUtil(unittest.TestCase):
@@ -43,6 +45,16 @@ class TestUtil(unittest.TestCase):
         self.assertEqual(parsed, {'test': '1', 'booo': '2'})
         self.assertEqual(env_to_str(parsed), env)
 
+    def test_to_uid(self):
+        with patch('pwd.getpwnam') as getpw:
+            m = Mock()
+            m.pw_uid = '1000'
+            getpw.return_value = m
+            uid = to_uid(u'user')
+            self.assertEqual('1000', uid)
+            uid = to_uid('user')
+            self.assertEqual('1000', uid)
+
     def test_to_uidgid(self):
         self.assertRaises(ValueError, to_uid, 'xxxxxxx')
         self.assertRaises(ValueError, to_gid, 'xxxxxxx')
@@ -78,8 +90,10 @@ class TestUtil(unittest.TestCase):
 
         self.assertRaises(KeyError, getpwuid, uid_max + 1)
         self.assertRaises(KeyError, getpwuid, uid_min - 1)
-        self.assertRaises(KeyError, getgrgid, gid_max + 1)
-        self.assertRaises(KeyError, getgrgid, gid_min - 1)
+        # getgrid may raises overflow error on mac/os x, fixed in python2.7.5
+        # see http://bugs.python.org/issue17531
+        self.assertRaises((KeyError, OverflowError), getgrgid, gid_max + 1)
+        self.assertRaises((KeyError, OverflowError), getgrgid, gid_min - 1)
 
     def test_replace_gnu_args(self):
         repl = replace_gnu_args
@@ -128,8 +142,3 @@ class TestUtil(unittest.TestCase):
         self.assertEquals('thats an int 2',
                           repl('thats an int ((me))', prefix=None,
                           me=2))
-
-    def test_strict_parser(self):
-        cp = StrictConfigParser()
-        bad_ini = os.path.join(os.path.dirname(__file__), 'bad.ini')
-        self.assertRaises(ValueError, cp.read, bad_ini)
