@@ -4,13 +4,17 @@ import os
 import threading
 import time
 
-from zmq.eventloop import ioloop
-
+from circus._zmq import ioloop
 from circus.tests.support import TestCircus, poll_for, truncate_file
 from circus.stream import QueueStream
 from circus.watcher import Watcher
 from circus.process import UNEXISTING
 
+import warnings
+
+warnings.filterwarnings('ignore',
+                        module='threading', message='sys.exc_clear')
+
 
 class TestWatcher(TestCircus):
 
@@ -107,7 +111,6 @@ class TestWatcher(TestCircus):
         truncate_file(self.test_file)  # make sure we have a clean slate
         # expect at least one restart (max_age and restart), in less than 5s
         self.assertTrue(poll_for(self.test_file, 'QUITSTART'))
-
         current_pids = self.pids()
         self.assertEqual(len(current_pids), 1)
         self.assertNotEqual(initial_pids, current_pids)
@@ -181,7 +184,7 @@ class SomeWatcher(threading.Thread):
                    'sys.stdout.write(\':\'.join(sys.path)); '
                    ' sys.stdout.flush()"') % sys.executable
 
-            self.loop = ioloop.IOLoop.instance()
+            self.loop = ioloop.IOLoop()
             self.watcher = Watcher('xx', cmd, copy_env=True, copy_path=True,
                                    stdout_stream=qstream, loop=self.loop,
                                    **self.kw)
