@@ -9,18 +9,21 @@ import re
 import sys
 import shlex
 import time
+import socket
 from zmq import ssh
 from ConfigParser import (ConfigParser, MissingSectionHeaderError,
                           ParsingError, DEFAULTSECT)
 
-from psutil.error import AccessDenied, NoSuchProcess
-from psutil import Process
+from psutil import AccessDenied, NoSuchProcess, Process
+
+from circus.py3compat import string_types
 
 
 # default endpoints
 DEFAULT_ENDPOINT_DEALER = "tcp://127.0.0.1:5555"
 DEFAULT_ENDPOINT_SUB = "tcp://127.0.0.1:5556"
 DEFAULT_ENDPOINT_STATS = "tcp://127.0.0.1:5557"
+DEFAULT_ENDPOINT_MULTICAST = "upd://237.219.251.97:12027"
 
 
 try:
@@ -235,7 +238,7 @@ def to_uid(name):
         except KeyError:
             raise ValueError("%r isn't a valid user id" % name)
 
-    if not isinstance(name, str):
+    if not isinstance(name, string_types):
         raise TypeError(name)
 
     try:
@@ -253,11 +256,14 @@ def to_gid(name):
         try:
             grp.getgrgid(name)
             return name
-        except KeyError:
+        # getgrid may raises overflow error on mac/os x, fixed in python2.7.5
+        # see http://bugs.python.org/issue17531
+        except (KeyError, OverflowError):
             raise ValueError("No such group: %r" % name)
 
-    if not isinstance(name, str):
+    if not isinstance(name, string_types):
         raise TypeError(name)
+
     try:
         return grp.getgrnam(name).gr_gid
     except KeyError:
@@ -518,7 +524,8 @@ class StrictConfigParser(ConfigParser):
                 if mo:
                     sectname = mo.group('header')
                     if sectname in self._sections:
-                        raise ValueError('Duplicate section %r' % sectname)
+                        # we're extending/overriding, we're good
+                        cursect = self._sections[sectname]
                     elif sectname == DEFAULTSECT:
                         cursect = self._defaults
                     else:
@@ -539,6 +546,9 @@ class StrictConfigParser(ConfigParser):
                     if mo:
                         optname, vi, optval = mo.group('option', 'vi', 'value')
                         optname = self.optionxform(optname.rstrip())
+                        # We don't want to override.
+                        if optname in cursect:
+                            continue
                         # This check is fine because the OPTCRE cannot
                         # match if it would set optval to None
                         if optval is not None:
@@ -644,3 +654,35 @@ def load_virtualenv(watcher):
             path = venv_path
 
         watcher.env['PYTHONPATH'] = path
+
+
+def create_udp_socket(mcast_addr, mcast_port):
+    """Create an udp multicast socket for circusd cluster auto-discovery.
+    Mcas_addr must be between 224.0.0.0 and 239.255.255.255
+    """
+    try:
+        ip_splitted = map(int, mcast_addr.split('.'))
+        mcast_port = int(mcast_port)
+    except ValueError:
+        raise ValueError('Wrong UDP multicast_endpoint configuration. Should '
+                         'looks like: "%r"' % DEFAULT_ENDPOINT_MULTICAST)
+
+    if ip_splitted[0] < 224 or ip_splitted[0] > 239:
+        raise ValueError('The multicast address is not valid should be '
+                         'between 224.0.0.0 and 239.255.255.255')
+
+    any_addr = "0.0.0.0"
+    sock = socket.socket(socket.AF_INET, socket.SOCK_DGRAM, socket.IPPROTO_UDP)
+    # Allow reutilization of addr
+    sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEADDR, 1)
+    # Some platform exposes SO_REUSEPORT
+    if hasattr(socket, 'SO_REUSEPORT'):
+        sock.setsockopt(socket.SOL_SOCKET, socket.SO_REUSEPORT, 1)
+    # Put packet ttl to max
+    sock.setsockopt(socket.IPPROTO_IP, socket.IP_MULTICAST_TTL, 255)
+    # Register socket to multicast group
+    sock.setsockopt(socket.IPPROTO_IP, socket.IP_ADD_MEMBERSHIP,
+                    socket.inet_aton(mcast_addr) + socket.inet_aton(any_addr))
+    # And finally bind all interfaces
+    sock.bind((any_addr, mcast_port))
+    return sock
